**Repository Organizer** : Repo organizer 
###################################################################################

Basic features:
  - cloning list of repositories
  - checkout master, any branch or commit id
  - apply patch to the same
  - New Run clears all the repos checkedout previously and starts fresh
  - dir must be an absolute path
  - patch file path is relative to where the python code is being run

Latest documentation of reporg :

  * `reporg.pdf  <https://gitlab.com/riscv_verification/reporg/-/jobs/artifacts/master/raw/reporg.pdf?job=doc>`_
